==> python-tcxparser-0.7.0.tar.gz: python-tcxparser-0.7.0/README.md <==
# python-tcxparser

[ ![Codeship Status for vkurup/python-tcxparser](https://codeship.com/projects/73da6380-712d-0132-3214-62f5102d8589/status?branch=master)](https://codeship.com/projects/54578)

python-tcxparser is a minimal parser for Garmin's TCX file format. It
is not in any way exhaustive. It extracts just enough data to allow me
to post data from my Garmin ForeRunner 410 watch to
[DailyMile's](http://dailymile.com) API.

Data extracted:
 - latitude & longitude of start point of workout
 - type of workout (running, walking, etc)
 - time of completion of workout (in ISO UTC)
 - distance of workout (in meters)
 - duration of workout (in seconds)
 - calories burned during workout (as estimated by device)
 - average, max and min heart rate during workout
 - average pace during workout
 - average altitude during workout

## Installation

    pip install python-tcxparser

## Usage

    >>> import tcxparser
    >>> tcx = tcxparser.TCXParser('/home/vinod/Downloads/20121226-212953.tcx')
    >>> # Duration of workout in seconds
    ... tcx.duration
    1992.78
    >>> # latitude/longitude at start of workout
    ... tcx.latitude
    35.951880198
    >>> tcx.longitude
    -79.0931872185
    >>> tcx.activity_type
    'running'
    >>> # ISO UTC timestamp when workout completed
    ... tcx.completed_at
    '2012-12-26T22:03:05Z'
    >>> # distance of workout in meters
    ... tcx.distance
    4686.31103516
    >>> tcx.distance_units
    'meters'
    >>> # calories burned (as reported by device)
    ... tcx.calories
    379

## Contact
Please contact me with any questions: Vinod Kurup (vinod@kurup.com)

==> python-tcxparser-0.7.1.tar.gz: python-tcxparser-0.7.1/README.md <==
# python-tcxparser

[ ![Codeship Status for vkurup/python-tcxparser](https://codeship.com/projects/eb924480-4493-0134-5e03-3a611b6d72e6/status?branch=master)](https://codeship.com/projects/168475)

python-tcxparser is a minimal parser for Garmin's TCX file format. It
is not in any way exhaustive. It extracts just enough data to allow me
to post data from my Garmin ForeRunner 410 watch to
[DailyMile's](http://dailymile.com) API.

Data extracted:
 - latitude & longitude of start point of workout
 - type of workout (running, walking, etc)
 - time of completion of workout (in ISO UTC)
 - distance of workout (in meters)
 - duration of workout (in seconds)
 - calories burned during workout (as estimated by device)
 - average, max and min heart rate during workout
 - average pace during workout
 - average altitude during workout
 - ascent and descent of workout
 - max and min altitude
 - time stamp of each data point (in ISO UTC)

## Installation

    pip install python-tcxparser

## Usage

    >>> import tcxparser
    >>> tcx = tcxparser.TCXParser('/home/vinod/Downloads/20121226-212953.tcx')
    >>> # Duration of workout in seconds
    ... tcx.duration
    1992.78
    >>> # latitude/longitude at start of workout
    ... tcx.latitude
    35.951880198
    >>> tcx.longitude
    -79.0931872185
    >>> tcx.activity_type
    'running'
    >>> # ISO UTC timestamp when workout completed
    ... tcx.completed_at
    '2012-12-26T22:03:05Z'
    >>> # distance of workout in meters
    ... tcx.distance
    4686.31103516
    >>> tcx.distance_units
    'meters'
    >>> # calories burned (as reported by device)
    ... tcx.calories
    379

## Contact
Please contact me with any questions: Vinod Kurup (vinod@kurup.com)
